@@ -5,7 +5,8 @@ from unittest.mock import patch, Mock
 
 from google.api_core.exceptions import GoogleAPIError
 from google.cloud import bigquery
-from google.cloud.bigquery import QueryJob, QueryPriority, LoadJob, LoadJobConfig, SchemaField, ExtractJob
+from google.cloud.bigquery import QueryJob, QueryPriority, LoadJob, LoadJobConfig, SchemaField, ExtractJob, \
+    QueryJobConfig
 from google.cloud.bigquery.schema import _parse_schema_resource
 from google.cloud.bigquery.table import Row, TableReference
 
@@ -30,16 +31,24 @@ class TestEmsBigqueryClient(TestCase):
         self.client_mock = Mock()
         self.query_job_mock = Mock(QueryJob)
         self.query_job_mock.priority = "INTERACTIVE"
+        self.query_job_mock.create_disposition = None
+        self.query_job_mock.write_disposition = None
         self.query_config = EmsQueryJobConfig(destination_project_id="some_destination_project_id",
                                               destination_dataset="some_dataset",
                                               destination_table="some_table")
 
+    def test_properties(self, bigquery_module_patch: bigquery):
+        ems_bigquery_client = self.__setup_client(bigquery_module_patch, None, "valhalla")
+
+        self.assertEqual(ems_bigquery_client.project_id, "some-project-id")
+        self.assertEqual(ems_bigquery_client.location, "valhalla")
+
     def test_run_async_query_submitsBatchQueryAndReturnsJobId(self, bigquery_module_patch: bigquery):
         ems_bigquery_client = self.__setup_client(bigquery_module_patch)
 
         result_job_id = ems_bigquery_client.run_async_query(self.QUERY, ems_query_job_config=self.query_config)
 
-        bigquery_module_patch.Client.assert_called_once_with("some-project-id")
+        bigquery_module_patch.Client.assert_called_once_with("some-project-id", location="EU")
         arguments = self.client_mock.query.call_args_list[0][1]
         assert arguments["query"] == self.QUERY
         assert arguments["location"] == "EU"
@@ -56,7 +65,7 @@ class TestEmsBigqueryClient(TestCase):
 
         ems_bigquery_client.run_async_query(self.QUERY, ems_query_job_config=query_config)
 
-        bigquery_module_patch.Client.assert_called_once_with("some-project-id")
+        bigquery_module_patch.Client.assert_called_once_with("some-project-id", location="EU")
         arguments = self.client_mock.query.call_args_list[0][1]
         self.assertEqual(arguments["job_config"].destination.project, "some-project-id")
 
@@ -131,7 +140,6 @@ class TestEmsBigqueryClient(TestCase):
 
         self.assertEqual(result_job_id, expected_job_id)
 
-
     def test_run_sync_query_submitsInteractiveQueryAndReturnsWithResultIterator(self, bigquery_module_patch: bigquery):
         ems_bigquery_client = self.__setup_client(bigquery_module_patch,
                                                   [
@@ -208,6 +216,8 @@ class TestEmsBigqueryClient(TestCase):
         load_job_mock.job_id = "123"
         load_job_mock.query = "SELECT 1"
         load_job_mock.state = "DONE"
+        load_job_mock.write_disposition = None
+        load_job_mock.create_disposition = None
         load_job_mock.error_result = None
         load_job_mock.source_uris = ["gs://some-bucket-id/some-blob-id"]
         destination = Mock(TableReference)
@@ -253,6 +263,23 @@ class TestEmsBigqueryClient(TestCase):
         self.assertEqual(result[0].query_config.destination_dataset, None)
         self.assertEqual(result[0].query_config.destination_table, None)
 
+    def test_get_job_list_returnsJobWithEmsQueryJobConfigWithDispositionsConvertedCorrectly(self, bigquery_module_patch: bigquery):
+        bigquery_module_patch.Client.return_value = self.client_mock
+        self.query_job_mock.job_id = "123"
+        self.query_job_mock.query = "SELECT 1"
+        self.query_job_mock.state = "DONE"
+        self.query_job_mock.write_disposition = "WRITE_APPEND"
+        self.query_job_mock.create_disposition = "CREATE_IF_NEEDED"
+        self.client_mock.list_jobs.return_value = [self.query_job_mock]
+
+        ems_bigquery_client = EmsBigqueryClient("some-project-id")
+        job_list_iterable = ems_bigquery_client.get_job_list()
+
+        result = list(job_list_iterable)
+        self.assertEqual(result[0].query_config.write_disposition, EmsWriteDisposition.WRITE_APPEND)
+        self.assertEqual(result[0].query_config.create_disposition, EmsCreateDisposition.CREATE_IF_NEEDED)
+
+
     def test_get_job_list_returnsJobWithEmsQueryJobConfigWithSetDestination(self, bigquery_module_patch: bigquery):
         bigquery_module_patch.Client.return_value = self.client_mock
         self.query_job_mock.job_id = "123"
@@ -366,6 +393,24 @@ class TestEmsBigqueryClient(TestCase):
         self.assertRaises(RetryLimitExceededError,
                           ems_bigquery_client.relaunch_failed_jobs, "prefixed", MIN_CREATION_TIME)
 
+    def test_wait_for_job_done_delegatesCallToOriginalJob(self, bigquery_module_patch: bigquery):
+        bigquery_module_patch.Client.return_value = self.client_mock
+        self.client_mock.get_job.return_value = self.query_job_mock
+        self.query_job_mock.job_id = "1234"
+        self.query_job_mock.priority = "INTERACTIVE"
+        self.query_job_mock.state = "DONE"
+        self.query_job_mock.result.return_value = self.query_job_mock
+
+        timeout = 123.
+        ems_bigquery_client = EmsBigqueryClient("some-project-id")
+
+        job = ems_bigquery_client.wait_for_job_done("job_id", timeout)
+
+        self.query_job_mock.result.assert_called_with(timeout=timeout)
+        self.assertIsInstance(job, EmsQueryJob)
+        self.assertEqual(job.job_id, "1234")
+        self.assertEqual(job.state, EmsJobState.DONE)
+
     def __create_query_job_mock(self, job_id: str, has_error: bool):
         error_result = {'reason': 'someReason', 'location': 'query', 'message': 'error occurred'}
         query_job_mock = Mock(QueryJob)
@@ -374,12 +419,15 @@ class TestEmsBigqueryClient(TestCase):
         query_job_mock.destination = None
         query_job_mock.query = "SIMPLE QUERY"
         query_job_mock.state = "DONE"
+        query_job_mock.create_disposition = None
+        query_job_mock.write_disposition = None
         query_job_mock.error_result = error_result if has_error else None
         return query_job_mock
 
     def __setup_client(self, bigquery_module_patch, return_value=None, location=None):
         project_id = "some-project-id"
         bigquery_module_patch.Client.return_value = self.client_mock
+        self.client_mock.project = "some-project-id"
         self.client_mock.query.return_value = self.query_job_mock
         self.query_job_mock.job_id = self.JOB_ID
         if location is not None:
